// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/components/text_inputs/cubit/text_input_cubit.dart';

class TextInputThemeResolver extends ThemeResolver<TextInputStyle,
    TextInputThemeExtension, TextInputState> {
  const TextInputThemeResolver({
    required this.customStyleFn,
  });

  @override
  TextInputStyle? computeExtensionValueFn(
    BuildContext context,
    TextInputThemeExtension? themeExtension, {
    TextInputState? extra,
  }) {
    TextInputStyle? style;
    switch (extra?.controlState) {
      case ControlState.disabled:
        style = themeExtension?.disabledStyle;
        break;
      case ControlState.focused:
        style = themeExtension?.focusedStyle;
        break;
      case ControlState.hovered:
      case ControlState.tapped:
      case ControlState.normal:
      case null:
        style = themeExtension?.normalStyle;
        break;
    }

    if (extra?.isInvalid ?? false) {
      style = themeExtension?.invalidStyle;
    }

    return style;
  }

  @override
  TextInputThemeExtension? getDefaultExtension(
    BuildContext context,
  ) =>
      TextInputThemeExtensionDefault.from(Theme.of(context));

  @override
  final TextInputStyle? Function(
    BuildContext context, {
    TextInputState? extra,
  }) customStyleFn;
}
