// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';

class TopBarThemeExtensionImpl extends TopBarThemeExtension {
  const TopBarThemeExtensionImpl({
    super.iconTheme,
    super.backgroundColors,
    super.selectedIndicatorColors,
    super.selectedIndicatorSize,
    super.dividerColor,
    super.titleStyle,
    super.subtitleStyle,
  });

  factory TopBarThemeExtensionImpl.light({ThemeData? theme}) {
    theme ??= ThemeData.light();
    return TopBarThemeExtensionImpl(
      backgroundColors: const MultiColor.single(
        Color.fromRGBO(246, 246, 246, 1),
      ),
      dividerColor: const Color.fromRGBO(36, 38, 42, 0.1),
      selectedIndicatorColors:
          const MultiColor.single(Color.fromRGBO(36, 38, 42, 1)),
      titleStyle: theme.textTheme.bodyMedium?.copyWith(
        fontWeight: FontWeight.bold,
        color: const Color.fromRGBO(36, 38, 42, 1),
        fontSize: 18,
      ),
      subtitleStyle: theme.textTheme.bodyMedium?.copyWith(
        fontWeight: FontWeight.w400,
        color: const Color.fromRGBO(36, 38, 42, 1),
        fontSize: 18,
      ),
      iconTheme: const IconThemeData(color: Color.fromRGBO(36, 38, 42, 1)),
    );
  }

  factory TopBarThemeExtensionImpl.dark({ThemeData? theme}) {
    theme ??= ThemeData.dark();
    return TopBarThemeExtensionImpl(
      backgroundColors: const MultiColor([
        Color.fromRGBO(44, 50, 56, 1),
        Color.fromRGBO(39, 47, 61, 1),
        Color.fromRGBO(44, 50, 56, 1),
      ]),
      dividerColor: const Color.fromRGBO(255, 255, 255, 0.1),
      selectedIndicatorColors: const MultiColor.single(Colors.white),
      titleStyle: theme.textTheme.bodyMedium?.copyWith(
        fontWeight: FontWeight.bold,
        fontSize: 18,
      ),
      subtitleStyle: theme.textTheme.bodyMedium?.copyWith(
        fontWeight: FontWeight.w400,
        fontSize: 18,
      ),
      iconTheme: const IconThemeData(color: Colors.white),
    );
  }
}
